@@ -1,38 +1,38 @@
-from .config import get_settings, Settings, StorageType, DatabaseType
+import functools
+from typing import Awaitable, Callable, Type
+
+from fastapi import FastAPI
+from fastapi.middleware.gzip import GZipMiddleware
+from starlette.middleware.cors import CORSMiddleware
+
+from .config import DatabaseType, Settings, StorageType, get_settings
 from .exception_handlers import setup_exception_handlers
 from .exceptions import (
-    DatabaseError,
-    StorageError,
-    HTTPException,
-    NotImplementedError,
-    UnknownError,
     BadRequestError,
-    UnauthorizedError,
+    DatabaseError,
     ForbiddenError,
+    HTTPException,
     NotFoundError,
-)
-from .utils import (
-    force_async,
-    force_sync,
-    sizeof_fmt,
-    resolve_dotted_path,
-    get_logger,
-    logger,
-    get_current_app,
-    get_remote_schema,
-    get_now,
-    get_timezone,
-    async_get,
+    NotImplementedError,
+    StorageError,
+    UnauthorizedError,
+    UnknownError,
 )
 from .models import CamelModel
 from .responses import UJSONResponse
-
-from typing import Type, Callable, Awaitable
-from starlette.middleware.cors import CORSMiddleware
-from fastapi import FastAPI
-from fastapi.middleware.gzip import GZipMiddleware
-
-import functools
+from .utils import (
+    async_get,
+    force_async,
+    force_sync,
+    get_current_app,
+    get_logger,
+    get_now,
+    get_remote_schema,
+    get_timezone,
+    logger,
+    resolve_dotted_path,
+    sizeof_fmt,
+)
 
 
 def create_app(
@@ -106,5 +106,11 @@ async def start_app(app: FastAPI):
 
     setup_db(app)
     setup_storage(app)
+    try:
+        from fa_common.gitlab import setup_gitlab
+
+        setup_gitlab(app)
+    except ValueError:
+        pass  # App probably doesn't want to use gitlab
 
     await create_indexes()
