@@ -1,7 +1,7 @@
 import logging
 import os
 from enum import Enum
-from typing import List, Set, Optional
+from typing import List, Optional, Set
 
 from dotenv import load_dotenv
 from pydantic import AnyUrl, BaseSettings, SecretBytes, SecretStr
@@ -23,7 +23,7 @@ class DatabaseType(str, Enum):
 
 
 class Settings(BaseSettings):
-    VERSION: str = "0.4.5"
+    VERSION: str = "0.5.0"
     API_VERSION: int = 1
     API_PRE_PATH: str = f"/api/v{API_VERSION}"
 
@@ -40,6 +40,10 @@ class Settings(BaseSettings):
     MINIO_ENDPOINT: Optional[str] = None
     MINIO_SSL: bool = False
 
+    GITLAB_PRIVATE_TOKEN: Optional[str] = None
+    GITLAB_GROUP_ID: Optional[int] = None
+    GITLAB_URL: Optional[str] = "https://gitlab.com/"
+
     BUCKET_NAME: str = ""
     BUCKET_PREFIX: str = ""
     BUCKET_USER_FOLDER: str = "user-storage/"
