@@ -1,21 +1,20 @@
 from io import BytesIO
+from typing import List, Optional, Union
+
+from fastapi import UploadFile
 from minio import Minio, Object
 from minio.error import (
     BucketAlreadyExists,
     BucketAlreadyOwnedByYou,
-    ResponseError,
     NoSuchKey,
+    ResponseError,
 )
-from typing import List, Optional, Union
-from fastapi import UploadFile
+
+from fa_common import StorageError, force_async, get_current_app
+from fa_common import logger as LOG
+from fa_common import sizeof_fmt
+
 from .base_client import BaseClient
-from fa_common import (
-    force_async,
-    get_current_app,
-    logger as LOG,
-    sizeof_fmt,
-    StorageError,
-)
 from .model import File
 
 
