@@ -1,8 +1,10 @@
 import os
-import pytest
 from io import BytesIO
+
+import pytest
 from fastapi import FastAPI, UploadFile
-from fa_common import create_app, utils, start_app
+
+from fa_common import create_app, start_app, utils
 from fa_common.storage import get_storage_client
 
 from .conftest import clean_env
